==> haskell-wizards-1.0.3-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wizards
version:              1.0.3
visibility:           public
id:                   wizards-1.0.3-8xJG8hOtcx42IvHEzzqTdS
key:                  wizards-1.0.3-8xJG8hOtcx42IvHEzzqTdS
license:              BSD-3-Clause
maintainer:           liamoc@cse.unsw.edu.au
author:               Liam O'\''Connor-Davis
synopsis:
    High level, generic library for interrogative user interfaces

description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.

    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.

    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.


    See the github page for examples on usage:

    <http://www.github.com/liamoc/wizards>

    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.

category:             User Interfaces
abi:                  f8f5c1f2246fa3c421f0ee09946bd1aa
exposed:              True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure

import-dirs:          /usr/lib/ghc-8.10.4/site-local/wizards-1.0.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/wizards-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/wizards-1.0.3
hs-libraries:         HSwizards-1.0.3-8xJG8hOtcx42IvHEzzqTdS
depends:
    base-4.14.1.0 containers-0.6.2.1
    control-monad-free-0.6.2-KoqhQBnZmRQDE5o4UpBgfa haskeline-0.8.0.1
    mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html:         /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wizards-1.0.3-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wizards
version:              1.0.3
visibility:           public
id:                   wizards-1.0.3-D6F1Ie8nXml21cuChbk09x
key:                  wizards-1.0.3-D6F1Ie8nXml21cuChbk09x
license:              BSD-3-Clause
maintainer:           liamoc@cse.unsw.edu.au
author:               Liam O'\''Connor-Davis
synopsis:
    High level, generic library for interrogative user interfaces

description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.

    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.

    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.


    See the github page for examples on usage:

    <http://www.github.com/liamoc/wizards>

    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.

category:             User Interfaces
abi:                  ac541a33479fc087540af9f10a30f8ae
exposed:              True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure

import-dirs:          /usr/lib/ghc-8.10.5/site-local/wizards-1.0.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wizards-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/wizards-1.0.3
hs-libraries:         HSwizards-1.0.3-D6F1Ie8nXml21cuChbk09x
depends:
    base-4.14.2.0 containers-0.6.4.1
    control-monad-free-0.6.2-6nHvGxzfOoN2NFMaDlBoMl haskeline-0.8.0.1
    mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html:         /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
